<?php

/**
 * @file
 * Contains \Drupal\tcmb\Plugin\Block\TcmbCurrencyBlock
 */

namespace Drupal\tcmb\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\block\Annotation\block;
use Drupal\Core\Annotation\Translation;

/**
 * Provides a 'Tcmb Currency' block.
 *
 * @Block (
 *  id = "tcmb_currency_block",
 *  category = @Translation("Tcmb"),
 *  admin_label = @Translation("Tcmb: currency")
 * )
 */
class TcmbCurrencyBlock extends BlockBase {
  public function build() {
    $config = \Drupal::config('tcmb.settings');
    $records = db_select('tcmb', 't')
      ->fields('t', array(
        'updated',
      ))
      ->range(0, 1)
      ->orderBy('updated', 'DESC')
      ->execute()
      ->fetchassoc();
    $updated = date('Y-m-d', strtotime($records['updated']));
    $tcmb_currency_codes = $config->get('tcmb_currency_codes', array());
    $records = db_select('tcmb', 't')
      ->fields('t', array(
        'currency_name',
        'currency_code',
        'updated',
        'buying',
        'selling',
      ))
      ->condition('currency_code', $tcmb_currency_codes, 'IN')
      ->condition('updated', $updated)
      ->groupBy('currency_code')
      ->groupBy('currency_name')
      ->groupBy('updated')
      ->groupBy('buying')
      ->groupBy('selling');
    $results = $records->execute()->fetchAll(\PDO::FETCH_ASSOC);
    $header = array(t('Currency'), t('Buying'), t('Selling'));
    $rows = array();
    $build = array(
      '#type' => 'table',
      '#header' => $header,
    );
    foreach ($results as $result) {
      $title = $result['currency_name'];
      $image = drupal_get_path('module', 'tcmb') . '/png/' . strtolower($result['currency_code']) . '.png';
      $id = $result['currency_name'];
      $build[$id]['image'] = array(
        '#theme' => 'image',
        '#uri' => $image,
        '#alt' => $title,
        '#title' => $title,
        '#suffix' => " " . $result['currency_code'],
      );
      $build[$id]['buy'] = array(
        '#markup' => $result['buying'],
      );
      $build[$id]['sell'] = array(
        '#markup' => $result['selling'],
      );
    }
    return array(
      '#markup' => drupal_render($build),
      '#suffix' => ($config->get('tcmb_show_currency_block_footer')) ? t('Exchange rates are updated once a day on 15:30 on weekdays.') : '',
    );
  }
  public function defaultConfiguration() {
    $config = \Drupal::config('tcmb.settings');
    $records = db_select('tcmb', 't')
      ->fields('t', array(
        'updated',
      ))
      ->range(0, 1)
      ->orderBy('updated', 'DESC')
      ->execute()
      ->fetchassoc();
    $updated = date('Y-m-d', strtotime($records['updated']));
    $tcmb_currency_codes = $config->get('tcmb_currency_codes', array());
    $records = db_select('tcmb', 't')
      ->fields('t', array(
        'currency_name',
        'currency_code',
        'updated',
        'buying',
        'selling',
      ))
      ->condition('currency_code', $tcmb_currency_codes, 'IN')
      ->condition('updated', $updated)
      ->groupBy('currency_code')
      ->groupBy('currency_name')
      ->groupBy('updated')
      ->groupBy('buying')
      ->groupBy('selling');
    $results = $records->execute()->fetchAll(\PDO::FETCH_ASSOC);
    return array(
      'label' => ($config->get('tcmb_show_currency_block_title')) ? t('TCMB rates for @updated', array('@updated' => date('d-m-Y', strtotime($results[0]['updated'])))) : '',
    );
  }
}
